#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FIFTEEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FIFTEEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/fifteen.hpp>

#endif
